package theme

type Default struct {
}

func (theme *Default) Template() string {
	return `
<!DOCTYPE html>
<html lang="en">

<head>
  <meta charset="UTF-8">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>{{ .Page.Title }}</title>
  <style>
    html {
      height: 100%;
    }

    body {
      width: 100% !important;
      height: 100%;
      margin: 0;
      font-size: .96rem;
      line-height: 1.4;
      background-color: #F2F4F6;
      color: #64687E;
      -webkit-text-size-adjust: none;
      font-family: Helvetica Neue, Tahoma, Arial, PingFangSC-Regular, Hiragino Sans GB, Microsoft Yahei, sans-serif;
      -webkit-font-smoothing: antialiased;
      touch-action: manipulation;
      text-size-adjust: none;
    }

    .container {
      max-width: 560px;
      height: 100%;
      margin: 0 auto;
      background-color: white;
    }

    .container-inner {
      padding: 1rem;
    }

	.action-block{
		margin: 30px 0 20px 0;
		text-align: center;
	}

    .text-success {
      color: #20c55c;
    }

    .text-danger {
      color: #ff0476;
    }

    .text-center {
      text-align: center;
    }

    article {
      line-height: 1.6rem
    }

    article h1,
    article h2,
    article h3,
    article h4 {
      color: #232323;
      margin-bottom: 1.28rem;
    }

 	a {
      font-style: none;
      text-decoration: none;
    }

    article p {
      margin-bottom: 1rem;
    }

    .preview-label {
      min-width: 4em;
      text-align: justify;
      text-align-last: justify;
    }

    .preview-value {
      text-align: right;
      display: block;
      overflow: hidden;
      word-break: normal;
      word-wrap: break-word;
      color: rgba(0, 0, 0, 0.9);
      flex: 1 1 auto !important;
    }

    .grid {
      padding: 1rem 0;
    }
	
    .grid h4 {
      margin-top: 0;
      margin-bottom: .68rem;
    }

    .row {
      display: flex;
      justify-content: flex-start;
      line-height: 2;
    }

    .button {
      padding: .8rem 2rem;
      color: white;
      background-color: #727cf5;
      border-radius: .25rem;
    }

	.invite-code {
		font-size: 32px;
    	letter-spacing: .6rem;
		color: #454742;
	}
	
	.copyright {
		text-align: center;
		font-size: .9rem;
		color: #8c8c86;
		margin: 50px 0 10px 0;
	}
	
    .cell {
      flex: 1 1 auto !important;
    }
  </style>
</head>

<body>
  <div class="container">
    <div class="container-inner">
      <article>
		{{ if .Page.Head }}<h1>{{ .Page.Head }}</h1>{{ end }}
		{{ with .Page.Intros }}
			{{ if gt (len .) 0 }}
			  {{ range $line := . }}
				<p>{{ $line }}</p>
			  {{ end }}
			{{ end }}
		{{ end }}
		{{ with .Page.Actions }}
			{{ if gt (len .) 0 }}
				{{ range $action := . }}
					{{ if $action.Instructions }} <p> {{ $action.Instructions }} </p> {{ end }}
					{{ if $action.InviteCode }}
						<div class="action-block"><span class="invite-code">{{ $action.InviteCode }}</span></div>
					{{ else if $action.Button }}
						<div class="action-block">
							{{ if $action.Button.Color }}
							<a class="button" href="{{ $action.Button.Url }}" style="background-color:{{ $action.Button.Color }}">{{ $action.Button.Text }}</a>
							{{ else }}
							<a class="button" href="{{ $action.Button.Url }}" >{{ $action.Button.Text }}</a>
							{{ end }}
						</div>
					{{ end }}
				{{ end }}
			{{ end }}
		{{ end }}
		{{ with .Page.Entries }}
			{{ if gt (len .) 0 }}
				{{ range $entry := . }}
				<div class="grid">
					{{if $entry.Title }}<h4>{{ $entry.Title }}</h4>{{ end }}
					{{ with $entry.Items }}
						{{ if gt (len .) 0 }}
						  {{ range $label,$value := . }}
							<div class="row">
							  <div class="preview-label">{{ $label }}</div>
							  <div class="preview-value">
							  {{ if $value.Theme }}
							    <span class="text-{{ $value.Theme }}">{{ $value.Content }}</span>
							  {{ else if $value.Color }}
								<span style="color:{{ $value.Theme }}">{{ $value.Content }}</span>
							  {{ else }}
								{{ $value.Content }}
							  {{ end }}
							  </div>
						    </div>
						  {{ end }}
						{{ end }}
					{{ end }}
				</div>
				{{ end }}
			{{ end }}
		{{ end }}
		{{ with .Page.Outros }}
			{{ if gt (len .) 0 }}
			  {{ range $line := . }}
				<p>{{ $line }}</p>
			  {{ end }}
			{{ end }}
		{{ end }}
		{{ if .Page.Copyright }}<div class="copyright">{{ .Page.Copyright }}</div>{{ end }}
      </article>
    </div>
  </div>
</body>
</html>
`
}
